==> kmplayer_0.8.0-1.tar.gz: kmplayer-0.8.0/src/mediaobject.h <==
/**
  This file belong to the KMPlayer project, a movie player plugin for Konqueror
  Copyright (C) 2007  Koos Vriezen <koos.vriezen@gmail.com>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**/

#ifndef _KMPLAYER__MEDIA_OBJECT_H_
#define _KMPLAYER__MEDIA_OBJECT_H_

#include <config.h>

#include "kmplayerplaylist.h"

typedef struct _GdkPixbufAnimation GdkPixbufAnimation;
typedef struct _GdkPixbufAnimationIter GdkPixbufAnimationIter;
typedef struct _GdkPixbufLoader GdkPixbufLoader;

namespace KMPlayer {

extern const unsigned int event_media_ready;
extern const unsigned int event_img_updated;
extern const unsigned int event_img_anim_finished;

class Control;


/*
 * Class that creates MediaObject and keeps track objects
 */
class KMPLAYER_EXPORT MediaManager {
public:
    enum MediaType { Audio, AudioVideo, Image, Text };
    //typedef QValueList <MediaObject *> MediaList;

    MediaManager (Control *ctrl);
    ~MediaManager ();

    MediaObject *createMedia (MediaType type, Node *node);

    //MediaList &medias () { return m_media_objects; }
    Control *control () const { return m_control; }

private:
    //MediaList m_media_objects;
    Control *m_control;
};


//------------------------%<----------------------------------------------------

/*
 * Abstract base of MediaObject types, handles downloading
 */

class KMPLAYER_EXPORT MediaObject : public AsyncJobInterface {
    friend class MediaManager;
public:
    virtual MediaManager::MediaType type () const = 0;

    virtual bool play () = 0;
    virtual void pause () {}
    virtual void unpause () {}
    virtual void stop () {}
    /*virtual*/ void destroy ();

    bool wget (const String &url);
    void killWGet ();
    void clearData ();
    String mimetype ();
    bool downloading () const;

    Mrl *mrl ();
    ByteArray &rawData () { return data; }

private:
    virtual void jobData (Job *job, ByteArray &data);
    virtual void jobResult (Job *job);

protected:
    MediaObject (MediaManager *manager, Node *node);
    virtual ~MediaObject ();

    virtual void ready (const String &url);

    MediaManager *m_manager;
    NodePtrW m_node;
    String url;
    ByteArray data;
    String mime;
    Job *job;
};


//------------------------%<----------------------------------------------------

/*
 * MediaObject for audio/video, groups Mrl, Process and Viewer
 */

class KMPLAYER_NO_EXPORT AudioVideoMedia : public MediaObject {
    friend class MediaManager;
public:
    //enum Request { ask_nothing, ask_play, ask_stop, ask_delete };

    AudioVideoMedia (MediaManager *manager, Node *node);

    MediaManager::MediaType type () const { return MediaManager::AudioVideo; }

    virtual bool play ();
    virtual void stop ();
    virtual void pause ();
    virtual void unpause ();

    //Request request;
    bool ignore_pause;

protected:
    ~AudioVideoMedia ();
};


//------------------------%<----------------------------------------------------

/*
 * MediaObject for (animated)images
 */

struct KMPLAYER_NO_EXPORT ImageData {
    ImageData( const String & img);
    ~ImageData();
    Image *image;
private:
    String url;
};

typedef SharedPtr <ImageData> ImageDataPtr;
typedef WeakPtr <ImageData> ImageDataPtrW;

class KMPLAYER_NO_EXPORT ImageMedia : public MediaObject {
public:
    ImageMedia (MediaManager *manager, Node *node);

    MediaManager::MediaType type () const { return MediaManager::Image; }

    bool play ();
    void stop ();
    void pause ();
    void unpause ();

    void setUrl (const String & url);
    bool isEmpty ();
    bool movieTimer ();
    ImageDataPtr cached_img;

protected:
    ~ImageMedia ();

    void ready (const String &url);

private:
    GdkPixbufAnimation *img_movie;
    GdkPixbufAnimationIter *img_movie_iter;
    GdkPixbufLoader *pix_loader;
    int img_movie_timer;
    int timeout;
};

//------------------------%<----------------------------------------------------

/*
 * MediaObject for text
 */
class KMPLAYER_NO_EXPORT TextMedia : public MediaObject {
public:
    TextMedia (MediaManager *manager, Node *node);

    MediaManager::MediaType type () const { return MediaManager::Text; }

    bool play ();

    String text;
    int default_font_size;

protected:
    ~TextMedia ();

    void ready (const String &url);
};

} // namespace

#endif

==> kmplayer_0.8.2-1.tar.gz: kmplayer-0.8.2/src/mediaobject.h <==
/**
  This file belong to the KMPlayer project, a movie player plugin for Konqueror
  Copyright (C) 2007  Koos Vriezen <koos.vriezen@gmail.com>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**/

#ifndef _KMPLAYER__MEDIA_OBJECT_H_
#define _KMPLAYER__MEDIA_OBJECT_H_

#include <config.h>

#include "kmplayerplaylist.h"

typedef struct _GdkPixbufAnimation GdkPixbufAnimation;
typedef struct _GdkPixbufAnimationIter GdkPixbufAnimationIter;
typedef struct _GdkPixbufLoader GdkPixbufLoader;

namespace KMPlayer {

extern const unsigned int event_media_ready;
extern const unsigned int event_img_updated;
extern const unsigned int event_img_anim_finished;

class Control;


/*
 * Class that creates MediaObject and keeps track objects
 */
class KMPLAYER_EXPORT MediaManager {
public:
    enum MediaType { Audio, AudioVideo, Image, Text };
    //typedef QValueList <MediaObject *> MediaList;

    MediaManager (Control *ctrl);
    ~MediaManager ();

    MediaObject *createMedia (MediaType type, Node *node);

    //MediaList &medias () { return m_media_objects; }
    Control *control () const { return m_control; }

private:
    //MediaList m_media_objects;
    Control *m_control;
};


//------------------------%<----------------------------------------------------

/*
 * Abstract base of MediaObject types, handles downloading
 */

class KMPLAYER_EXPORT MediaObject : public AsyncJobInterface {
    friend class MediaManager;
public:
    virtual MediaManager::MediaType type () const = 0;

    virtual bool play () = 0;
    virtual void pause () {}
    virtual void unpause () {}
    virtual void stop () {}
    /*virtual*/ void destroy ();

    virtual bool wget (const String &url);
    void killWGet ();
    void clearData ();
    String mimetype ();
    bool downloading () const;

    Mrl *mrl ();
    ByteArray &rawData () { return data; }

private:
    virtual void jobData (Job *job, ByteArray &data);
    virtual void jobResult (Job *job);

protected:
    MediaObject (MediaManager *manager, Node *node);
    virtual ~MediaObject ();

    virtual void ready (const String &url);

    MediaManager *m_manager;
    NodePtrW m_node;
    String url;
    ByteArray data;
    String mime;
    Job *job;
};


//------------------------%<----------------------------------------------------

/*
 * MediaObject for audio/video, groups Mrl, Process and Viewer
 */

class KMPLAYER_NO_EXPORT AudioVideoMedia : public MediaObject {
    friend class MediaManager;
public:
    //enum Request { ask_nothing, ask_play, ask_stop, ask_delete };

    AudioVideoMedia (MediaManager *manager, Node *node);

    MediaManager::MediaType type () const { return MediaManager::AudioVideo; }

    virtual bool play ();
    virtual void stop ();
    virtual void pause ();
    virtual void unpause ();

    //Request request;
    bool ignore_pause;

protected:
    ~AudioVideoMedia ();
};


//------------------------%<----------------------------------------------------

/*
 * MediaObject for (animated)images
 */

struct KMPLAYER_NO_EXPORT ImageData {
    enum ImageFlags {
        ImageAny=0, ImagePixmap=0x1, ImageAnimated=0x2, ImageScalable=0x4
    };
    ImageData( const String & img);
    ~ImageData();
    void setImage (Image *img);
    void copyImage (Surface *s, int w, int h, cairo_surface_t *similar);
    bool isEmpty () const {
         return !image && !surface; }

    unsigned short width;
    unsigned short height;
    short flags;
    bool has_alpha;
private:
    Image *image;
    cairo_surface_t *surface;
    String url;
};

typedef SharedPtr <ImageData> ImageDataPtr;
typedef WeakPtr <ImageData> ImageDataPtrW;

class KMPLAYER_NO_EXPORT ImageMedia : public MediaObject {
public:
    ImageMedia (MediaManager *manager, Node *node);

    MediaManager::MediaType type () const { return MediaManager::Image; }

    bool play ();
    void stop ();
    void pause ();
    void unpause ();

    bool wget (const String &url);
    bool isEmpty () const;
    bool movieTimer ();

    ImageDataPtr cached_img;

protected:
    ~ImageMedia ();

    void ready (const String &url);

private:
    void setupImage ();

    GdkPixbufAnimation *img_movie;
    GdkPixbufAnimationIter *img_movie_iter;
    GdkPixbufLoader *pix_loader;
    int img_movie_timer;
    int timeout;
};

//------------------------%<----------------------------------------------------

/*
 * MediaObject for text
 */
class KMPLAYER_NO_EXPORT TextMedia : public MediaObject {
public:
    TextMedia (MediaManager *manager, Node *node);

    MediaManager::MediaType type () const { return MediaManager::Text; }

    bool play ();

    String text;
    int default_font_size;

protected:
    ~TextMedia ();

    void ready (const String &url);
};

} // namespace

#endif
